django-sitegate documentation
=============================

http://github.com/idlesign/django-sitegate

*django-sitegate is a reusable application for Django to ease sign up & sign in processes.*

This application will handle most common user registration flows for you.


Requirements
------------

1. Python 2.7+ or 3.3+
2. Django 1.5+
3. Django Auth contrib enabled


Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    signup_custom
    signin_custom
    utils


Get involved into django-sitegate
---------------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose a feature you can do that at https://github.com/idlesign/django-sitegate/issues

**Write code.** If you are eager to participate in application development, fork it at https://github.com/idlesign/django-sitegate, write your code, whether it should be a bugfix or a feature implementation, and make a pull request right from the forked project page.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest for the others — publish them.


The tip
-------

If the application is not what you want for user registration, you might be interested in considering the other choices — https://www.djangopackages.com/grids/g/registration/
